@@ -8,21 +8,21 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Uncompress::RawInflate  2.021 ;
-use IO::Compress::Base::Common  2.021 qw(:Status createSelfTiedObject);
-use IO::Uncompress::Adapter::Inflate  2.021 ;
-use IO::Uncompress::Adapter::Identity 2.021 ;
-use IO::Compress::Zlib::Extra 2.021 ;
-use IO::Compress::Zip::Constants 2.021 ;
+use IO::Uncompress::RawInflate  2.023 ;
+use IO::Compress::Base::Common  2.023 qw(:Status createSelfTiedObject);
+use IO::Uncompress::Adapter::Inflate  2.023 ;
+use IO::Uncompress::Adapter::Identity 2.023 ;
+use IO::Compress::Zlib::Extra 2.023 ;
+use IO::Compress::Zip::Constants 2.023 ;
 
-use Compress::Raw::Zlib  2.021 qw(crc32) ;
+use Compress::Raw::Zlib  2.023 qw(crc32) ;
 
 BEGIN
 {
     eval { require IO::Uncompress::Adapter::Bunzip2 ;
            import  IO::Uncompress::Adapter::Bunzip2 } ;
-   eval { require IO::Uncompress::Adapter::UnLzma ;
-           import  IO::Uncompress::Adapter::UnLzma } ;
+#   eval { require IO::Uncompress::Adapter::UnLzma ;
+#           import  IO::Uncompress::Adapter::UnLzma } ;
 }
 
 
@@ -30,7 +30,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnzipError, %headerLookup);
 
-$VERSION = '2.021';
+$VERSION = '2.023';
 $UnzipError = '';
 
 @ISA    = qw(Exporter IO::Uncompress::RawInflate);
@@ -63,7 +63,7 @@ sub unzip
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common  2.021 qw(:Parse);
+    use IO::Compress::Base::Common  2.023 qw(:Parse);
 
     
     return (
@@ -650,34 +650,34 @@ sub _readZipHeader($)
 
         *$self->{Uncomp} = $obj;
     }
-    elsif ($compressedMethod == ZIP_CM_LZMA)
-    {
-        return $self->HeaderError("Unsupported Compression format $compressedMethod")
-            if ! defined $IO::Uncompress::Adapter::UnLzma::VERSION ;
-        
-        *$self->{Type} = 'zip-lzma';
-        my $LzmaHeader;
-        $self->smartReadExact(\$LzmaHeader, 4)
-                or return $self->saveErrorString(undef, "Truncated file");
-        my ($verHi, $verLo)   = unpack ("CC", substr($LzmaHeader, 0, 2));
-        my $LzmaPropertiesSize   = unpack ("v", substr($LzmaHeader, 2, 2));
-
-
-        my $LzmaPropertyData;
-        $self->smartReadExact(\$LzmaPropertyData, $LzmaPropertiesSize)
-                or return $self->saveErrorString(undef, "Truncated file");
-        #my $LzmaInfo = unpack ("C", substr($LzmaPropertyData, 0, 1));    
-        #my $LzmaDictSize = unpack ("V", substr($LzmaPropertyData, 1, 4));    
-
-        # Create an LZMA_Alone header 
-        $self->pushBack($LzmaPropertyData . 
-                $uncompressedLength->getPacked_V64());
-
-        my $obj =
-        IO::Uncompress::Adapter::UnLzma::mkUncompObject();
-
-        *$self->{Uncomp} = $obj;
-    }
+#    elsif ($compressedMethod == ZIP_CM_LZMA)
+#    {
+#        return $self->HeaderError("Unsupported Compression format $compressedMethod")
+#            if ! defined $IO::Uncompress::Adapter::UnLzma::VERSION ;
+#        
+#        *$self->{Type} = 'zip-lzma';
+#        my $LzmaHeader;
+#        $self->smartReadExact(\$LzmaHeader, 4)
+#                or return $self->saveErrorString(undef, "Truncated file");
+#        my ($verHi, $verLo)   = unpack ("CC", substr($LzmaHeader, 0, 2));
+#        my $LzmaPropertiesSize   = unpack ("v", substr($LzmaHeader, 2, 2));
+#
+#
+#        my $LzmaPropertyData;
+#        $self->smartReadExact(\$LzmaPropertyData, $LzmaPropertiesSize)
+#                or return $self->saveErrorString(undef, "Truncated file");
+#        #my $LzmaInfo = unpack ("C", substr($LzmaPropertyData, 0, 1));    
+#        #my $LzmaDictSize = unpack ("V", substr($LzmaPropertyData, 1, 4));    
+#
+#        # Create an LZMA_Alone header 
+#        $self->pushBack($LzmaPropertyData . 
+#                $uncompressedLength->getPacked_V64());
+#
+#        my $obj =
+#        IO::Uncompress::Adapter::UnLzma::mkUncompObject();
+#
+#        *$self->{Uncomp} = $obj;
+#    }
     elsif ($compressedMethod == ZIP_CM_STORE)
     {
         # TODO -- add support for reading uncompressed
@@ -979,7 +979,48 @@ Defaults to 0.
 
 =item C<< Append => 0|1 >>
 
-TODO
+The behaviour of this option is dependent on the type of output data
+stream.
+
+=over 5
+
+=item * A Buffer
+
+If C<Append> is enabled, all uncompressed data will be append to the end of
+the output buffer. Otherwise the output buffer will be cleared before any
+uncompressed data is written to it.
+
+=item * A Filename
+
+If C<Append> is enabled, the file will be opened in append mode. Otherwise
+the contents of the file, if any, will be truncated before any uncompressed
+data is written to it.
+
+=item * A Filehandle
+
+If C<Append> is enabled, the filehandle will be positioned to the end of
+the file via a call to C<seek> before any uncompressed data is
+written to it.  Otherwise the file pointer will not be moved.
+
+=back
+
+When C<Append> is specified, and set to true, it will I<append> all uncompressed 
+data to the output data stream.
+
+So when the output is a filehandle it will carry out a seek to the eof
+before writing any uncompressed data. If the output is a filename, it will be opened for
+appending. If the output is a buffer, all uncompressed data will be appened to
+the existing buffer.
+
+Conversely when C<Append> is not specified, or it is present and is set to
+false, it will operate as follows.
+
+When the output is a filename, it will truncate the contents of the file
+before writing any uncompressed data. If the output is a filehandle
+its position will not be changed. If the output is a buffer, it will be
+wiped before any uncompressed data is output.
+
+Defaults to 0.
 
 =item C<< MultiStream => 0|1 >>
 
@@ -1470,7 +1511,7 @@ See L<IO::Uncompress::Unzip::FAQ|IO::Uncompress::Unzip::FAQ/"Compressed files an
 
 =head1 SEE ALSO
 
-L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Uncompress::AnyInflate>, L<IO::Uncompress::AnyUncompress>
+L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Compress::Xz>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Uncompress::AnyInflate>, L<IO::Uncompress::AnyUncompress>
 
 L<Compress::Zlib::FAQ|Compress::Zlib::FAQ>
 
